@@ -14,10 +14,12 @@ def _utm_zone(lat, lon):
     :return: UTM zone in format 'EPSG:32XYZ'
     """
     zone = (math.floor((lon + 180)/6) % 60) + 1
+    str_zone = str(zone).zfill(2)
+    
     if lat > 0:
-        return 'EPSG:326' + str(zone)
+        return 'EPSG:326' + str_zone
     else:
-        return 'EPSG:325' + str(zone)
+        return 'EPSG:325' + str_zone
 
 def get_utm_zone(crs, transform, shape):
     """
@@ -34,4 +36,4 @@ def get_utm_zone(crs, transform, shape):
     center_xy = xy(transform, shape[0] / 2, shape[1] / 2)
     center_latlon = warp.transform(crs, CRS_LATLON, [center_xy[0]], [center_xy[1]])
     #calc zone
-    return _utm_zone(center_latlon[1][0], center_latlon[0][0])
\ No newline at end of file
+    return _utm_zone(center_latlon[1][0], center_latlon[0][0])
