@@ -4,7 +4,7 @@ import warnings
 import shapely
 import shapely.geometry
 from shapely.geometry import Polygon, MultiPolygon, GeometryCollection
-from shapely.geometry.polygon import orient
+from shapely.ops import orient
 
 from rasterio.warp import transform_geom
 
@@ -63,20 +63,22 @@ class Feature:
             f = self
 
         shape = f.shape
-        if isinstance(shape, MultiPolygon):
-            shape = MultiPolygon([orient(poly) for poly in shape])
-        elif isinstance(shape, Polygon):
-            shape = orient(shape)
-        elif isinstance(shape, GeometryCollection):
-            contours = []
-            for geo_object in shape:
-                if isinstance(geo_object, Polygon):
-                    contours.append(geo_object)
-                elif isinstance(geo_object, MultiPolygon):
-                    contours += list(geo_object)
-            shape = MultiPolygon([orient(poly) for poly in shape])
-        else:
+        if shape.is_empty:
+            # Empty geometries are not allowed in FeatureCollections,
+            # but here it may occur due to reprojection which can eliminate small geiometries
+            # This case is processed separately as orient(POLYGON_EMPTY) raises an exception
+            # TODO: do not return anything on empty polygon and ignore such features in FeatureCollection.geojson
             shape = Polygon()
+        else:
+            try:
+                shape = orient(shape)
+            except Exception as e:
+                # Orientation is really not a crucial step, it follows the geojson standard,
+                # but not oriented polygons can be read by any instrument. So, ni case of any troubles with orientation
+                # we just fall back to not-oriented version of the same geometry
+                warnings.warn(f'Polygon orientation failed: {str(e)}. Returning initial shape instead',
+                              RuntimeWarning)
+                shape = f.shape
 
         f = Feature(shape, properties=f.properties)
         data = {
@@ -121,7 +123,7 @@ class FeatureCollection:
     def _valid(self, features):
         valid_features = []
         for f in features:
-            if not f.geometry.get('coordinates'): # remove possible empty shapes
+            if not f.geometry.get('coordinates'):  # remove possible empty shapes
                 warnings.warn('Empty geometry detected. This geometry have been removed from collection.',
                               RuntimeWarning)
             else:
@@ -189,9 +191,9 @@ class FeatureCollection:
                 
         return cls(features)
 
-    def save(self, fp):
+    def save(self, fp, indent=None):
         with open(fp, 'w') as f:
-            json.dump(self.geojson, f)
+            json.dump(self.geojson, f, indent=indent)
 
     @property
     def geojson(self):
